@@ -7,7 +7,12 @@ __version__ = '0.1.7'
 import sys
 
 from . import callbacks
-from .callbacks import printer
+from .callbacks import (
+    printer
+    , set_default_callback
+    , enable_printing
+    , disable_printing
+)
 from pyrofiler.threading import threaded, threaded_with_queue
 from pyrofiler import measures
 from pyrofiler.decorators_foreground import (
